@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2014, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2014, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -304,7 +306,7 @@ Shell_options::Shell_options(
   add_startup_options(true)
     (cmdline("--ssh=<value>"), "Make SSH tunnel connection using"
         "Uniform Resource Identifier. "
-        "Format: [user[:pass]@]host[:port]")
+        "Format: [user@]host[:port]")
     (&storage.ssh.identity_file, "", cmdline("--ssh-identity-file=<file>"),
         "File from which the private key for public key authentication is "
         "read.",
@@ -456,9 +458,10 @@ Shell_options::Shell_options(
         cmdline("--fido-register-factor=<name>"),
         "Specifies authentication factor, for which registration needs to be "
         "done.")
-    (&storage.recreate_database, false, "recreateDatabase",
-        cmdline("--recreate-schema"), "Drop and recreate the specified schema. "
-        "Schema will be deleted if it exists!");
+    (cmdline("--recreate-schema"), "Drop and recreate the specified schema. "
+        "Schema will be deleted if it exists!", deprecated(m_on_warning, nullptr, [this](const std::string&, const char* ) {
+          storage.recreate_database = true;
+        }));
 
   add_startup_options(true)
     (cmdline("--mx", "--mysqlx"),
@@ -505,7 +508,7 @@ Shell_options::Shell_options(
         std::bind(
             &Shell_options::override_session_type, this, _1, _2))
     (cmdline("--js", "--javascript"), "Start in JavaScript mode.",
-#ifdef HAVE_V8
+#ifdef HAVE_JS
         [this](const std::string&, const char*) {
           storage.initial_mode = shcore::IShell_core::Mode::JavaScript;
         }
@@ -1202,6 +1205,12 @@ bool Shell_options::custom_cmdline_handler(Iterator *iterator) {
       iterator->next_no_value();
     }
   } else if ("--import" == option) {
+    m_on_warning(
+        "WARNING: The --import option was deprecated and will be removed in "
+        "a future version of the MySQL Shell. Please consider using the CLI "
+        "call for import-json instead.\nFor additional information: mysqlsh -- "
+        "util import-json --help");
+
     const auto cmdline = iterator->iterator();
 
     storage.import_args.push_back(cmdline->get());  // omit --import
