@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2025, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -2422,4 +2422,9 @@ TEST_F(Completer_frontend, bug_34365581) {
   execute("DROP SCHEMA ogÓrek;");
 }
 
+TEST_F(Completer_frontend, bug_37528585) {
+  execute("\\js");
+  EXPECT_NO_THROW(complete("shell.unexisting."));
+}
+
 }  // namespace mysqlsh
